@@ -22,13 +22,18 @@ def read_msms(
         file_root: str) -> Tuple[np.ndarray, np.ndarray, np.ndarray, List[str]]:
     """Read surface constituents from output files generated using MSMS.
 
-    :param name: file_root - Root name for loading .face and .vert files (produced by MSMS). Default location is data/tmp/{pdb_id}s
-    :param type: str
+        file_root: str
+            Root name for loading .face and .vert files (produced by MSMS). Default location is data/tmp/{pdb_id}s
    
-    :returns: numpy.ndarray - vertices
-    :returns: numpy.ndarray - faces
-    :returns: numpy.ndarray - vertex normals
-    :returns: list - List of res_id's from output_pdb_as_xyzrn()
+    Parameters:
+        numpy.ndarray:
+            vertices
+        numpy.ndarray:
+            faces
+        numpy.ndarray:
+            vertex normals
+        list:
+            list of res_id's from output_pdb_as_xyzrn()
     """
     vertfile = open(file_root + ".vert")
     meshdata = (vertfile.read().rstrip()).split("\n")
@@ -85,10 +90,11 @@ def output_pdb_as_xyzrn(pdb_file: str, xyzrn_file: str) -> None:
     """
     Converts a .pdb file to a .xyzrn file.
 
-    :param name: pdb_file - path to PDB File to convert (with extension)
-    :param type: str
-    :param name: xyzrn_file - path to the xyzrn File (with extension)
-    :param type: str
+    Parameters:
+        pdb_file: str
+            path to PDB File to convert (with extension)
+        xyzrn_file: str
+            path to the xyzrn File (with extension)
     """
     # get absolute path for xyzrn_file, needed for open
     xyzrn_file = os.path.join(os.getcwd(), xyzrn_file)
@@ -100,56 +106,71 @@ def output_pdb_as_xyzrn(pdb_file: str, xyzrn_file: str) -> None:
     struct = parser.get_structure(id=pdb_id, file=pdb_file)
     outfile = open(xyzrn_file, "w")
 
-    for atom in struct.get_atoms():
-        name = atom.get_name()
-        residue = atom.get_parent()
-        # Ignore hetatms.
-        if residue.get_id()[0] != " ":
-            continue
-        resname = residue.get_resname()
-        reskey = residue.get_id()[1]
-        chain = residue.get_parent().get_id()
-        atomtype = name[0]
+    i = 0
+    for model in struct:
+        for chain in model:
+            for residue in chain:
+                if residue.get_resname() == "HOH":
+                    continue
+                for atom in residue:
+                    name = atom.get_name()
+                    residue = atom.get_parent()
+                    # Ignore hetatms.
+                    if residue.get_id()[0] != " ":
+                        continue
+                    resname = residue.get_resname()
+                    reskey = residue.get_id()[1]
+                    chain = residue.get_parent().get_id()
+                    atomtype = name[0]
 
-        color = "Green"
-        coords = None
-        if atomtype in RADII and resname in POLAR_HYDROGENS:
-            if atomtype == "O":
-                color = "Red"
-            if atomtype == "N":
-                color = "Blue"
-            if atomtype == "H":
-                if name in POLAR_HYDROGENS[resname]:
-                    color = "Blue"  # Polar hydrogens
-            coords = "{:.06f} {:.06f} {:.06f}".format(atom.get_coord()[0],
-                                                      atom.get_coord()[1],
-                                                      atom.get_coord()[2])
-            insertion = "x"
-            if residue.get_id()[2] != " ":
-                insertion = residue.get_id()[2]
-            # this is the weird ID; the 9th column of the xyzrn file
-            full_id = "{}_{:d}_{}_{}_{}_{}".format(
-                chain,
-                residue.get_id()[1], insertion, resname, name, color)
-        if coords is not None:
-            outfile.write(coords + " " + RADII[atomtype] + " 1 " + full_id +
-                          "\n")
+                    color = "Green"
+                    coords = None
+                    if atomtype in RADII and resname in POLAR_HYDROGENS:
+                        if atomtype == "O":
+                            color = "Red"
+                        if atomtype == "N":
+                            color = "Blue"
+                        if atomtype == "H":
+                            if name in POLAR_HYDROGENS[resname]:
+                                color = "Blue"  # Polar hydrogens
+                        coords = "{:.06f} {:.06f} {:.06f}".format(atom.get_coord()[0],
+                                                                  atom.get_coord()[1],
+                                                                  atom.get_coord()[2])
+                        insertion = "x"
+                        if residue.get_id()[2] != " ":
+                            insertion = residue.get_id()[2]
+                        # this is the weird ID; the 9th column of the xyzrn file
+                        full_id = "{}_{:d}_{}_{}_{}_{}".format(
+                            chain,
+                            residue.get_id()[1], insertion, resname, name, color)
+                    if coords is not None:
+                        outfile.write(coords + " " + RADII[atomtype] + " 1 " + str(i) + " " + full_id +  
+                                      "\n")
+        i += 1
 
 
-def get_surface(out_path: str, density: float):
+def get_surface(out_path: str, density: float, center=[0, 0, 0]):
     """
     Wrapper function that reads in the output from the MSMS executable to build the protein surface.
 
-    :param name: out_path - path to output (output path from namechecker) directory. Usually data/tmp
-    :param type: str
-    :param name: density - Need to pass same density as used by the MSMS binary, as the face and vert files have the density included in their names. The variable is needed for loading these files.
-    :param type: bool
-        
-    :returns: numpy.ndarray - vertices
-    :returns: numpy.ndarray - faces
-    :returns: numpy.ndarray - vertex normals
-    :returns: list - List of res_id's from output_pdb_as_xyzrn()
-    :returns: dict - Dictionary: residues as keys, areas as values
+        out_path: str
+            path to output (output path from namechecker) directory. Usually data/tmp
+        density: bool
+            Need to pass same density as used by the MSMS binary, as the face and vert files have the density included in their names. The variable is needed for loading these files.
+        center: List[float], optional
+            Center of the atom cloud. Easily passed from DataHandler._centroid. Default: [0, 0, 0].
+            
+    Returns: 
+        numpy.ndarray:
+            vertices
+        numpy.ndarray:
+            faces
+        numpy.ndarray:
+            vertex normals
+        list:
+            list of res_id's from output_pdb_as_xyzrn()
+        dict:
+            dictionary: residues as keys, areas as values
     """
     file_base = os.path.abspath(out_path)
     file_base = f"{file_base}_out_{int(density * 10)}"
@@ -164,20 +185,24 @@ def get_surface(out_path: str, density: float):
     for line in ses_file:
         fields = line.split()
         areas[fields[3]] = fields[1]
-
-    return vertices, faces, normals, names, areas
+    
+    re_centered_verts = vertices - center
+    return re_centered_verts, faces, normals, names, areas
 
 
 def compute_normal(vertices: np.ndarray, faces: np.ndarray) -> np.ndarray:
     """
     Compute normals for the vertices and faces
 
-    :param name: vertices - Vertices of the mesh
-    :param type: np.ndarray 
-    :param name: faces - Faces of the mesh
-    :param type: np.ndarray 
+    Parameters:
+        vertices: np.ndarray 
+            Vertices of the mesh
+        faces: np.ndarray 
+            Faces of the mesh
     
-    :returns: np.ndarray - Normals of the mesh
+    Returns: 
+        np.ndarray:
+            Normals of the mesh
     """
     vertex = vertices.T
     face = faces.T
@@ -219,12 +244,15 @@ def crossp(x: np.ndarray, y: np.ndarray) -> np.ndarray:
     """
     Creates the cross product of two numpy arrays
 
-    :param name: x - Array 1
-    :param type: np.ndarray
-    :param name: y - Array 2
-    :param type: np.ndarray
+    Parameters:
+        x: np.ndarray
+            Array 1
+        y: np.ndarray
+            Array 2
 
-    :returns: np.ndarray - (Array 1) x (Array 2)
+    Returns: 
+        np.ndarray:
+            (Array 1) x (Array 2)
     """
     z = np.zeros((x.shape))
     z[0, :] = np.multiply(x[1, :], y[2, :]) - np.multiply(x[2, :], y[1, :])
@@ -235,22 +263,24 @@ def crossp(x: np.ndarray, y: np.ndarray) -> np.ndarray:
 def prepare_trimesh(vertices: np.ndarray,
                  faces: np.ndarray,
                  normals: np.ndarray = None,
-                 resolution: float = 1.0,
                  apply_fixes: bool = False):
     """
     Prepare the mesh surface given vertices and faces. Optionally, compute
     normals and apply fixes to mesh.
 
-    :param name: vertices - Surface vertices
-    :param type: np.ndarray
-    :param name: faces - Triangular faces on the mesh
-    :param type: np.ndarray
-    :param name: normals - Normals for each vertex
-    :param type: np.ndarray
-    :param name: apply_fixes - Optional application of fixes to mesh. Check fix_mesh for details on fixes. Default: False,
-    :param type: bool
+    Parameters:
+        vertices: np.ndarray
+            Surface vertices
+        faces: np.ndarray
+            Triangular faces on the mesh
+        normals: np.ndarray
+            Normals for each vertex
+        apply_fixes: bool
+            Optional application of fixes to mesh. Check fix_mesh for details on fixes. Default: False,
 
-    :returns: trimesh.Trimesh - Mesh
+    Returns: 
+        trimesh.Trimesh:
+            Mesh
     """
     tmp_mesh = trimesh.Trimesh(vertices, faces)
     
@@ -272,12 +302,15 @@ def fix_trimesh(mesh, resolution: float = 1.0):
     a certain threshold, removing degenerate triangles, splitting longer edges to
     a given target length, and collapsing shorter edges.
 
-    :param name: mesh - Mesh
-    :param type: trimesh.Trimesh
-    :param name: resolution - Maximum size of edge in the mesh
-    :param tyoe: float
+    Parameters:
+        mesh: trimesh.Trimesh
+            Mesh
+        resolution: float
+            Maximum size of edge in the mesh
 
-    :returns: trimesh.Trimesh - mesh with all fixes applied
+    Returns: 
+        trimesh.Trimesh:
+            mesh with all fixes applied
     """
     target_len = resolution
     mesh, _ = trimesh.remove_duplicated_vertices(mesh, 0.001)
@@ -323,4 +356,4 @@ def find_nearest_atom(coords, res_id, new_verts):
         lenr = len(res_id)
         full_res_id.append(res_id[loc])
         
-    return full_res_id
\ No newline at end of file
+    return full_res_id
